@@ -1,11 +1,11 @@
 from __future__ import annotations
 
+from _util import write_report
 from qiskit import QuantumCircuit
 from qiskit.qasm3 import dumps as qasm3_dumps
 from qiskit.qasm3 import loads as qasm3_loads
 
 from ariadne.verify.qcec import statevector_equiv
-from examples._util import write_report
 
 
 def build_circuit() -> QuantumCircuit:
