@@ -17,6 +17,7 @@ Cirq Features:
 from __future__ import annotations
 
 import importlib.util
+import logging
 import warnings
 from collections.abc import Callable, Generator
 from typing import Any
@@ -25,6 +26,8 @@ import numpy as np
 from qiskit import QuantumCircuit  # type: ignore[import-untyped]
 from qiskit.circuit import Parameter  # type: ignore[import-untyped]
 
+logger = logging.getLogger(__name__)
+
 
 class CirqBackend:
     """Cirq-based quantum backend with advanced noise modeling."""
@@ -273,9 +276,9 @@ class CirqBackend:
         }
 
         # Convert each instruction
-        for instruction, qubits_used, _clbits in circuit.data:
-            gate_name = instruction.name.lower()
-            cirq_qubits = [qubit_map[q] for q in qubits_used]
+        for instruction in circuit.data:
+            gate_name = instruction.operation.name.lower()
+            cirq_qubits = [qubit_map[q] for q in instruction.qubits]
 
             # Skip measurements and barriers for now
             if gate_name in ["measure", "barrier", "delay"]:
@@ -462,8 +465,8 @@ class CirqBackend:
                     info["device_qubits"] = len(self.device.qubits) if hasattr(self.device, "qubits") else "unknown"
                     info["device_gates"] = str(self.device.gateset) if hasattr(self.device, "gateset") else "unknown"
 
-            except Exception:
-                pass
+            except Exception as e:
+                logger.debug(f"Failed to get Cirq backend info: {e}")
 
         return info
 
