@@ -16,14 +16,30 @@ from typing import Any
 from qiskit import QuantumCircuit
 from qiskit.transpiler import PassManager
 from qiskit.transpiler.passes import (
-    Cancellation,
     CommutativeCancellation,
     Optimize1qGates,
-    Optimize2qGates,
     Unroll3qOrMore,
     UnrollCustomDefinitions,
 )
 
+# Handle Qiskit version compatibility for Optimize2qGates
+# Note: Optimize2qGates was removed in Qiskit 2.0+
+try:
+    from qiskit.transpiler.passes import Optimize2qGatesDecomposition as Optimize2qGates
+
+    HAS_OPTIMIZE_2Q = True
+except ImportError:
+    # Try alternate import name
+    try:
+        from qiskit.transpiler.passes import Optimize2qGates  # noqa: F401
+
+        HAS_OPTIMIZE_2Q = True
+    except ImportError:
+        # Optimize2qGates is not available in this Qiskit version
+        HAS_OPTIMIZE_2Q = False
+        # Create a dummy class to avoid NameError
+        Optimize2qGates = type("Optimize2qGates", (), {})
+
 try:
     from ariadne.core import get_logger
 except ImportError:
@@ -181,12 +197,13 @@ class GateFusionOptimizer(CircuitOptimizer):
 
         # For now, we'll use Qiskit's built-in optimization passes
         # which include some gate fusion
-        pass_manager = PassManager(
-            [
-                Optimize1qGates(),
-                Optimize2qGates(),
-            ]
-        )
+        passes = [Optimize1qGates()]
+
+        # Only add Optimize2qGates if available (removed in Qiskit 2.0+)
+        if HAS_OPTIMIZE_2Q and Optimize2qGates is not None:
+            passes.append(Optimize2qGates())
+
+        pass_manager = PassManager(passes)
 
         return pass_manager.run(circuit)
 
@@ -208,7 +225,6 @@ class GateCancellationOptimizer(CircuitOptimizer):
         # Apply gate cancellation
         pass_manager = PassManager(
             [
-                Cancellation(),
                 CommutativeCancellation(),
             ]
         )
@@ -244,14 +260,17 @@ class DepthReductionOptimizer(CircuitOptimizer):
         optimized = circuit.copy()
 
         # Apply depth reduction optimizations
-        pass_manager = PassManager(
-            [
-                Optimize1qGates(),
-                Optimize2qGates(),
-                Cancellation(),
-                CommutativeCancellation(),
-            ]
-        )
+        passes = [
+            Optimize1qGates(),
+        ]
+
+        # Only add Optimize2qGates if available (removed in Qiskit 2.0+)
+        if HAS_OPTIMIZE_2Q and Optimize2qGates is not None:
+            passes.append(Optimize2qGates())
+
+        passes.append(CommutativeCancellation())
+
+        pass_manager = PassManager(passes)
 
         optimized = pass_manager.run(optimized)
 
