@@ -107,20 +107,47 @@ def _simulate_stim(circuit: QuantumCircuit, shots: int) -> dict[str, int]:
 def _simulate_qiskit(circuit: QuantumCircuit, shots: int) -> dict[str, int]:
     logger = get_logger("router")
 
-    try:
-        from qiskit.providers.basic_provider import BasicProvider
-    except ImportError as exc:  # pragma: no cover - depends on qiskit extras
-        raise BackendUnavailableError("qiskit", "Qiskit provider not available") from exc
+    # Ensure circuit has measurements - required for getting counts
+    if circuit.num_clbits == 0:
+        circuit = circuit.copy()
+        circuit.measure_all()
 
     try:
-        provider = BasicProvider()
-        backend = provider.get_backend("basic_simulator")
+        from qiskit_aer import AerSimulator
+    except ImportError:
+        # Fallback to basic provider if Aer not available
+        try:
+            from qiskit.providers.basic_provider import BasicProvider
+        except ImportError as exc:  # pragma: no cover - depends on qiskit extras
+            raise BackendUnavailableError("qiskit", "Qiskit provider not available") from exc
+
+        try:
+            # Decompose circuit to basic gates for basic_simulator compatibility
+            from qiskit import transpile
+
+            decomposed_circuit = transpile(
+                circuit,
+                basis_gates=["u1", "u2", "u3", "cx", "id"],
+                optimization_level=0,
+            )
+            provider = BasicProvider()
+            backend = provider.get_backend("basic_simulator")
+            job = backend.run(decomposed_circuit, shots=shots)
+            counts = job.result().get_counts()
+            return {str(key): value for key, value in counts.items()}
+        except Exception as exc:
+            logger.log_simulation_error(exc, backend="qiskit")
+            raise SimulationError(f"Qiskit simulation failed: {exc}", backend="qiskit") from exc
+
+    # Use Aer simulator which supports more gates
+    try:
+        backend = AerSimulator()
         job = backend.run(circuit, shots=shots)
         counts = job.result().get_counts()
         return {str(key): value for key, value in counts.items()}
     except Exception as exc:
         logger.log_simulation_error(exc, backend="qiskit")
-        raise SimulationError(f"Qiskit simulation failed: {exc}", backend="qiskit") from exc
+        raise SimulationError(f"Qiskit Aer simulation failed: {exc}", backend="qiskit") from exc
 
 
 def _real_tensor_network_simulation(circuit: QuantumCircuit, shots: int) -> dict[str, int]:
@@ -157,7 +184,7 @@ def _simulate_jax_metal(circuit: QuantumCircuit, shots: int) -> dict[str, int]:
 
         # Use our new MetalBackend with hybrid approach
         backend = MetalBackend(allow_cpu_fallback=True)
-        result = backend.simulate(circuit, shots)
+        result = dict(backend.simulate(circuit, shots))
 
         # Log backend mode for debugging
         logger.debug(f"Metal backend executed in mode: {backend.backend_mode}")
@@ -205,7 +232,7 @@ def _simulate_cirq(circuit: QuantumCircuit, shots: int) -> dict[str, int]:
 
     try:
         backend = CirqBackend()
-        return backend.simulate(circuit, shots)
+        return dict(backend.simulate(circuit, shots))
     except Exception as exc:
         logger.log_simulation_error(exc, backend="cirq")
         raise SimulationError(f"Cirq simulation failed: {exc}", backend="cirq") from exc
@@ -222,7 +249,7 @@ def _simulate_pennylane(circuit: QuantumCircuit, shots: int) -> dict[str, int]:
 
     try:
         backend = PennyLaneBackend()
-        return backend.simulate(circuit, shots)
+        return dict(backend.simulate(circuit, shots))
     except Exception as exc:
         logger.log_simulation_error(exc, backend="pennylane")
         raise SimulationError(f"PennyLane simulation failed: {exc}", backend="pennylane") from exc
@@ -239,7 +266,7 @@ def _simulate_qulacs(circuit: QuantumCircuit, shots: int) -> dict[str, int]:
 
     try:
         backend = QulacsBackend()
-        return backend.simulate(circuit, shots)
+        return dict(backend.simulate(circuit, shots))
     except Exception as exc:
         logger.log_simulation_error(exc, backend="qulacs")
         raise SimulationError(f"Qulacs simulation failed: {exc}", backend="qulacs") from exc
@@ -256,7 +283,7 @@ def _simulate_pyquil(circuit: QuantumCircuit, shots: int) -> dict[str, int]:
 
     try:
         backend = PyQuilBackend()
-        return backend.simulate(circuit, shots)
+        return dict(backend.simulate(circuit, shots))
     except Exception as exc:
         logger.log_simulation_error(exc, backend="pyquil")
         raise SimulationError(f"PyQuil simulation failed: {exc}", backend="pyquil") from exc
@@ -273,12 +300,46 @@ def _simulate_braket(circuit: QuantumCircuit, shots: int) -> dict[str, int]:
 
     try:
         backend = BraketBackend()
-        return backend.simulate(circuit, shots)
+        return dict(backend.simulate(circuit, shots))
     except Exception as exc:
         logger.log_simulation_error(exc, backend="braket")
         raise SimulationError(f"Braket simulation failed: {exc}", backend="braket") from exc
 
 
+def _simulate_aws_braket(circuit: QuantumCircuit, shots: int) -> dict[str, int]:
+    """Simulate using AWS Braket backend."""
+    logger = get_logger("router")
+
+    try:
+        from .backends.braket_backend import AWSBraketBackend
+    except ImportError as exc:
+        raise BackendUnavailableError("aws_braket", "AWS Braket SDK not installed") from exc
+
+    try:
+        backend = AWSBraketBackend()
+        return dict(backend.simulate(circuit, shots))
+    except Exception as exc:
+        logger.log_simulation_error(exc, backend="aws_braket")
+        raise SimulationError(f"AWS Braket simulation failed: {exc}", backend="aws_braket") from exc
+
+
+def _simulate_azure_quantum(circuit: QuantumCircuit, shots: int) -> dict[str, int]:
+    """Simulate using Azure Quantum backend."""
+    logger = get_logger("router")
+
+    try:
+        from .backends.azure_backend import AzureQuantumBackend
+    except ImportError as exc:
+        raise BackendUnavailableError("azure_quantum", "Azure Quantum SDK not installed") from exc
+
+    try:
+        backend = AzureQuantumBackend()
+        return dict(backend.simulate(circuit, shots))
+    except Exception as exc:
+        logger.log_simulation_error(exc, backend="azure_quantum")
+        raise SimulationError(f"Azure Quantum simulation failed: {exc}", backend="azure_quantum") from exc
+
+
 def _simulate_qsharp(circuit: QuantumCircuit, shots: int) -> dict[str, int]:
     """Simulate using the Q# backend (skeleton, falls back to Qiskit)."""
     logger = get_logger("router")
@@ -290,7 +351,7 @@ def _simulate_qsharp(circuit: QuantumCircuit, shots: int) -> dict[str, int]:
 
     try:
         backend = QSharpBackend()
-        return backend.simulate(circuit, shots)
+        return dict(backend.simulate(circuit, shots))
     except Exception as exc:
         logger.log_simulation_error(exc, backend="qsharp")
         raise SimulationError(f"Q# simulation failed: {exc}", backend="qsharp") from exc
@@ -307,7 +368,7 @@ def _simulate_opencl(circuit: QuantumCircuit, shots: int) -> dict[str, int]:
 
     try:
         backend = OpenCLBackend()
-        return backend.simulate(circuit, shots)
+        return dict(backend.simulate(circuit, shots))
     except Exception as exc:
         logger.log_simulation_error(exc, backend="opencl")
         raise SimulationError(f"OpenCL simulation failed: {exc}", backend="opencl") from exc
@@ -394,7 +455,30 @@ def _sample_statevector_counts(circuit: QuantumCircuit, shots: int, seed: int |
 
 
 def _execute_simulation(circuit: QuantumCircuit, shots: int, routing_decision: RoutingDecision) -> SimulationResult:
-    """Execute simulation based on a routing decision, including fallback logic."""
+    """
+    Execute a simulation using the backend chosen by the router.
+
+    Parameters
+    ----------
+    circuit : QuantumCircuit
+        Circuit to execute.
+    shots : int
+        Number of samples to draw from the circuit.
+    routing_decision : RoutingDecision
+        Router output describing the recommended backend and confidence.
+
+    Returns
+    -------
+    SimulationResult
+        Counts, metadata, and routing explanation for the execution.
+
+    Raises
+    ------
+    ResourceExhaustionError
+        Raised when resource checks fail prior to execution.
+    SimulationError
+        Raised if the primary backend and the Qiskit fallback both fail.
+    """
     logger = get_logger("router")
     resource_manager = get_resource_manager()
 
@@ -403,14 +487,26 @@ def _execute_simulation(circuit: QuantumCircuit, shots: int, routing_decision: R
 
     # Resource checks can be disabled via config or env var for small/local runs
     cfg = get_config()
-    disable_checks_env = os.getenv("ARIADNE_DISABLE_RESOURCE_CHECKS", "").lower() in {"1", "true", "yes"}
-    do_resource_checks = bool(getattr(cfg.analysis, "enable_resource_estimation", True)) and not disable_checks_env
+    disable_checks_env = os.getenv("ARIADNE_DISABLE_RESOURCE_CHECKS", "").lower() in {
+        "1",
+        "true",
+        "yes",
+    }
+    do_resource_checks = (
+        bool(getattr(cfg.analysis, "enable_resource_estimation", True))
+        and not disable_checks_env
+        and routing_decision.confidence_score > 0  # Do not check for forced backends
+    )
 
     # Check resource availability
     if do_resource_checks:
         can_handle, reason = check_circuit_feasibility(circuit, backend_name)
         if not can_handle:
-            raise ResourceExhaustionError("memory", 0, resource_manager.get_resources().available_memory_mb)
+            raise ResourceExhaustionError(
+                f"memory: {reason}",
+                0,
+                resource_manager.get_resources().available_memory_mb,
+            )
 
     # Initialize result tracking
     fallback_reason = None
@@ -458,6 +554,10 @@ def _execute_simulation(circuit: QuantumCircuit, shots: int, routing_decision: R
             counts = _simulate_pyquil(circuit, shots)
         elif backend == BackendType.BRAKET:
             counts = _simulate_braket(circuit, shots)
+        elif backend == BackendType.AWS_BRAKET:
+            counts = _simulate_aws_braket(circuit, shots)
+        elif backend == BackendType.AZURE_QUANTUM:
+            counts = _simulate_azure_quantum(circuit, shots)
         elif backend == BackendType.QSHARP:
             counts = _simulate_qsharp(circuit, shots)
         elif backend == BackendType.OPENCL:
@@ -489,11 +589,12 @@ def _execute_simulation(circuit: QuantumCircuit, shots: int, routing_decision: R
                 backend=backend_name,
             ) from exc
 
-    elapsed = perf_counter() - start
+    finally:
+        # Always release resources if they were reserved
+        if reserved_resources and do_resource_checks:
+            resource_manager.release_resources(reserved_resources)
 
-    # Release resources
-    if reserved_resources and do_resource_checks:
-        resource_manager.release_resources(reserved_resources)
+    elapsed = perf_counter() - start
 
     # Log completion
     logger.log_simulation_complete(elapsed, shots, backend=backend_name)
@@ -522,7 +623,40 @@ def _execute_simulation(circuit: QuantumCircuit, shots: int, routing_decision: R
 
 
 def simulate(circuit: QuantumCircuit, shots: int = 1024, backend: str | None = None) -> SimulationResult:
-    """Convenience wrapper that routes and executes ``circuit``."""
+    """
+    Route and execute a quantum circuit on the most appropriate simulator.
+
+    Parameters
+    ----------
+    circuit : QuantumCircuit
+        Circuit to route and execute.
+    shots : int, optional
+        Number of samples to collect, by default 1024.
+    backend : str or None, optional
+        Explicit backend override (e.g. ``"qiskit"``). When ``None`` the router
+        selects the backend automatically.
+
+    Returns
+    -------
+    SimulationResult
+        Execution outcome with counts, metadata, and routing explanation.
+
+    Raises
+    ------
+    ValueError
+        If ``shots`` is negative or the backend override is unknown.
+    SimulationError
+        If the router fails to select an executable backend.
+
+    Examples
+    --------
+    >>> from qiskit import QuantumCircuit
+    >>> qc = QuantumCircuit(2)
+    >>> qc.h(0); qc.cx(0, 1); qc.measure_all()
+    >>> result = simulate(qc, shots=256)
+    >>> result.backend_used
+    <BackendType.QISKIT: 'qiskit'>
+    """
     logger = get_logger("router")
 
     # Validate inputs
@@ -560,10 +694,8 @@ def simulate(circuit: QuantumCircuit, shots: int = 1024, backend: str | None = N
         except ValueError as exc:
             raise ValueError(f"Unknown backend: {backend}") from exc
 
-        # Check if forced backend is available
-        can_handle, reason = check_circuit_feasibility(circuit, backend)
-        if not can_handle:
-            raise CircuitTooLargeError(circuit.num_qubits, circuit.depth(), backend)
+        # Allow backend override without feasibility check.
+        pass
 
         # Create a forced routing decision
         routing_decision = RoutingDecision(
@@ -577,15 +709,70 @@ def simulate(circuit: QuantumCircuit, shots: int = 1024, backend: str | None = N
 
         logger.info(f"Using forced backend: {backend}")
     else:
-        # Use Enhanced Router for optimal selection
+        # Optionally use the predictive model for selection
+        use_predictor = os.getenv("ARIADNE_ROUTING_PREDICT", "").lower() in {"1", "true", "yes"}
+        prefer_hybrid = os.getenv("ARIADNE_ROUTING_HYBRID", "").lower() in {"1", "true", "yes"}
+
         try:
-            routing_decision = enhanced_router.select_optimal_backend(circuit, strategy=RouterType.HYBRID_ROUTER)
+            if use_predictor:
+                from .route.performance_model import find_optimal_backend
+                from .route.routing_tree import get_available_backends
+
+                available = [BackendType(b) for b in get_available_backends() if b in BackendType._value2member_map_]
+                if available:
+                    best_backend, prediction = find_optimal_backend(circuit, available, optimize_for="time")
+                    routing_decision = RoutingDecision(
+                        circuit_entropy=0.0,
+                        recommended_backend=best_backend,
+                        confidence_score=0.8,
+                        expected_speedup=1.0,
+                        channel_capacity_match=1.0,
+                        alternatives=[(b, 0.0) for b in available if b != best_backend],
+                    )
+                else:
+                    routing_decision = enhanced_router.select_optimal_backend(
+                        circuit, strategy=RouterType.HYBRID_ROUTER
+                    )
+            elif prefer_hybrid:
+                # Use the hybrid planner to inform backend choice (advisory, not executing hybrid yet)
+                try:
+                    from .route.performance_prediction import PerformancePredictor
+
+                    predictor = PerformancePredictor()
+                    if predictor.should_use_hybrid_execution(circuit):
+                        plan = predictor.create_hybrid_execution_plan(circuit, shots=shots)
+                        # Pick the most frequent backend in segments as a practical monolithic choice
+                        from collections import Counter
+
+                        backends = [b for _seg, b in plan.segments]
+                        most_common_backend, _ = Counter(backends).most_common(1)[0]
+                        routing_decision = RoutingDecision(
+                            circuit_entropy=0.0,
+                            recommended_backend=most_common_backend,
+                            confidence_score=0.7,
+                            expected_speedup=plan.expected_speedup,
+                            channel_capacity_match=1.0,
+                            alternatives=[(b, 0.0) for b in set(backends) if b != most_common_backend],
+                        )
+                    else:
+                        routing_decision = enhanced_router.select_optimal_backend(
+                            circuit, strategy=RouterType.HYBRID_ROUTER
+                        )
+                except Exception:
+                    routing_decision = enhanced_router.select_optimal_backend(
+                        circuit, strategy=RouterType.HYBRID_ROUTER
+                    )
+            else:
+                routing_decision = enhanced_router.select_optimal_backend(circuit, strategy=RouterType.HYBRID_ROUTER)
         except Exception as exc:
             logger.error(f"Router failed to select backend: {exc}")
             raise SimulationError(f"Router failed: {exc}") from exc
 
     try:
         return _execute_simulation(circuit, shots, routing_decision)
+    except ResourceExhaustionError as exc:
+        logger.error(f"Resource exhaustion error: {exc}")
+        raise CircuitTooLargeError(circuit.num_qubits, circuit.depth(), backend) from exc
     except Exception as exc:
         logger.error(f"Simulation failed: {exc}")
         raise
