@@ -45,9 +45,9 @@ class TestQuantumAlgorithms:
             # Handle case where result has extra padding (spaces)
             actual_states = {state.replace(" ", "")[:n_qubits] for state in result.counts.keys()}
 
-            assert actual_states.issubset(
-                expected_states
-            ), f"GHZ state for {n_qubits} qubits produced unexpected states: {actual_states - expected_states}"
+            assert actual_states.issubset(expected_states), (
+                f"GHZ state for {n_qubits} qubits produced unexpected states: {actual_states - expected_states}"
+            )
 
             # Check that both states appear with roughly equal probability
             if len(actual_states) == 2:
@@ -93,9 +93,9 @@ class TestQuantumAlgorithms:
                 target_prob = result.counts[target_bitstring] / 1000
                 # Should have higher probability than uniform distribution
                 uniform_prob = 1.0 / (2**n_qubits)
-                assert (
-                    target_prob > uniform_prob
-                ), f"Grover's algorithm didn't amplify target state: {target_prob} <= {uniform_prob}"
+                assert target_prob > uniform_prob, (
+                    f"Grover's algorithm didn't amplify target state: {target_prob} <= {uniform_prob}"
+                )
 
     def test_variational_quantum_eigensolver(self) -> None:
         """Test VQE ansatz circuits."""
@@ -114,9 +114,9 @@ class TestQuantumAlgorithms:
             # For now, just verify the circuit executes successfully
             # Skip superposition check for MPS backend due to current limitations
             if result.backend_used != BackendType.MPS:
-                assert (
-                    len(result.counts) > 1
-                ), f"VQE ansatz should create superposition, got {result.counts} with backend {result.backend_used}"
+                assert len(result.counts) > 1, (
+                    f"VQE ansatz should create superposition, got {result.counts} with backend {result.backend_used}"
+                )
 
     def test_quantum_approximate_optimization(self) -> None:
         """Test QAOA circuits."""
@@ -219,7 +219,10 @@ class TestQuantumAlgorithms:
             (lambda: self._create_surface_code_circuit(3, 3), BackendType.STIM),
             (lambda: self._create_teleportation_circuit(), BackendType.STIM),
             # Non-Clifford circuits should use Metal or fallback
-            (lambda: self._create_vqe_ansatz(4), None),  # Could be Metal, CUDA, or Qiskit
+            (
+                lambda: self._create_vqe_ansatz(4),
+                None,
+            ),  # Could be Metal, CUDA, or Qiskit
             (lambda: self._create_parameterized_circuit(4, 3), None),
         ]
 
@@ -230,9 +233,9 @@ class TestQuantumAlgorithms:
             if expected_backend:
                 # Backend should match expected type (handle both enum and string)
                 if isinstance(result.backend_used, str):
-                    assert (
-                        result.backend_used == expected_backend.value
-                    ), f"Circuit routed to {result.backend_used}, expected {expected_backend.value}"
+                    assert result.backend_used == expected_backend.value, (
+                        f"Circuit routed to {result.backend_used}, expected {expected_backend.value}"
+                    )
                 else:
                     assert (
                         result.backend_used == expected_backend or str(result.backend_used) == expected_backend.value
